diff --git a/core/lib/Drupal/Core/Entity/EntityManager.php b/core/lib/Drupal/Core/Entity/EntityManager.php
index 6f2ce76..dbd3b91 100644
--- a/core/lib/Drupal/Core/Entity/EntityManager.php
+++ b/core/lib/Drupal/Core/Entity/EntityManager.php
@@ -321,8 +321,8 @@ public function clearCachedBundles() {
    *
    * @see https://www.drupal.org/node/2549139
    */
-  public function getBundleInfo($entity_type) {
-    return $this->container->get('entity_type.bundle.info')->getBundleInfo($entity_type);
+  public function getBundleInfo($entity_type_id) {
+    return $this->container->get('entity_type.bundle.info')->getBundleInfo($entity_type_id);
   }
 
   /**
diff --git a/core/lib/Drupal/Core/Entity/EntityTypeBundleInfo.php b/core/lib/Drupal/Core/Entity/EntityTypeBundleInfo.php
index 42d00a7..aa917c8 100644
--- a/core/lib/Drupal/Core/Entity/EntityTypeBundleInfo.php
+++ b/core/lib/Drupal/Core/Entity/EntityTypeBundleInfo.php
@@ -76,9 +76,9 @@ public function __construct(EntityTypeManagerInterface $entity_type_manager, Lan
   /**
    * {@inheritdoc}
    */
-  public function getBundleInfo($entity_type) {
+  public function getBundleInfo($entity_type_id) {
     $bundle_info = $this->getAllBundleInfo();
-    return isset($bundle_info[$entity_type]) ? $bundle_info[$entity_type] : [];
+    return isset($bundle_info[$entity_type_id]) ? $bundle_info[$entity_type_id] : [];
   }
 
   /**
diff --git a/core/lib/Drupal/Core/Entity/EntityTypeBundleInfoInterface.php b/core/lib/Drupal/Core/Entity/EntityTypeBundleInfoInterface.php
index 882f98b..e5869bf 100644
--- a/core/lib/Drupal/Core/Entity/EntityTypeBundleInfoInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityTypeBundleInfoInterface.php
@@ -21,8 +21,8 @@ public function getAllBundleInfo();
   /**
    * Gets the bundle info of an entity type.
    *
    * @param string $entity_type
    *   The entity type.
    *
    * @return array
    *   An array of bundle information where the outer array is keyed by the
@@ -30,7 +30,7 @@ public function getAllBundleInfo();
    *   The inner arrays are associative arrays of bundle information, such as
    *   the label for the bundle.
    */
-  public function getBundleInfo($entity_type);
+  public function getBundleInfo($entity_type_id_id);
 
   /**
    * Clears static and persistent bundles.
@@ -21,8 +21,8 @@ public function getAllBundleInfo();
    * Gets the bundle info of an entity type.
    *
-   * @param string $entity_type
-   *   The entity type.
+   * @param string $entity_type_id_id
+   *   The entity type ID.
    *
    * @return array
